#
# spec file for package superpaper
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           superpaper
Version:        2.1.0
Release:        3.9
Summary:        An advanced multi monitor wallpaper manager
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/hhannine/superpaper
Source:         https://github.com/hhannine/superpaper/archive/v%{version}.tar.gz#/superpaper-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-Pillow >= 7.0.0
BuildRequires:  python3-numpy >= 1.18.0
BuildRequires:  python3-screeninfo >= 0.6.1
BuildRequires:  python3-setuptools
BuildRequires:  python3-system_hotkey >= 1.0.3
BuildRequires:  python3-wxPython
BuildRequires:  python3-xcffib >= 0.8.0
BuildRequires:  python3-xpybutil >= 0.0.5
BuildRequires:  update-desktop-files
Requires:       python3-Pillow >= 7.0.0
Requires:       python3-numpy >= 1.18.0
Requires:       python3-screeninfo >= 0.6.1
Requires:       python3-system_hotkey >= 1.0.2
Requires:       python3-wxPython
Requires:       python3-xcffib >= 0.8.0
Requires:       python3-xpybutil >= 0.0.5
# this package used the python-rpm-macros singlespec system until May 2021.
Provides:       python3-superpaper = %{version}-%{release}
Obsoletes:      python3-superpaper < %{version}-%{release}
Provides:       python38-superpaper = %{version}-%{release}
Obsoletes:      python38-superpaper < %{version}-%{release}
BuildArch:      noarch

%description
Cross-platform wallpaper manager that focuses on multi-monitor support.
Features include ppi corrections, keyboard shortcuts, and slideshow.

%prep
%setup -q
# fix shebang
sed -i '/^#!/d' %{name}/__main__.py
# fix icon path
sed -i 's|share/icons/hicolor/256x256/apps|%{_datadir}/pixmaps|' setup.py

%build
%python3_build

%install
%python3_install
%suse_update_desktop_file %{name} DesktopSettings
%fdupes %{buildroot}%{python3_sitelib}

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png
%{python3_sitelib}/%{name}
%{python3_sitelib}/%{name}-%{version}*-info

%changelog
* Sat May  8 2021 Ben Greiner <code@bnavigator.de>
- Convert to non-singlespec. This is an app and building for
  multiple python3 flavors creates file conflicts.
* Wed Mar  3 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Do not build for python 3.6: not all dependencies exist (e.g
  numpy).
* Thu Oct 22 2020 andy great <andythe_great@pm.me>
- Update to version 2.1.0.
  * New features
  * Span groups: span wallpapers on groups of displays.
  * New tool to set the physical display positions for advanced
    span. Enables accurate fine tuning of dragged positions.
  * Control system wallpaper span setting. No more need to check
    the setting in the system settings.
  * Fixes
  * Fix out of order wallpaper changes when user and slideshow
    acted concurrently
  * Support capitalized file extensions
  * Default locale is now system locale
- Clean up spec file, update python-system_hotkey dependency.
* Sat May 23 2020 andy great <andythe_great@pm.me>
- Fix dependencies.
* Tue May 12 2020 andy great <andythe_great@pm.me>
- Update to version 2.0.2
  * Make wallpaper source browse and help dialogs resizable to
    accommodate different resolutions
  * Left double click on tray icon now opens wallpaper
    configuration
  * Adjust KDE detection to remove false positives
* Fri Apr 24 2020 andy great <andythe_great@pm.me>
- Update to version 2.0.0
  * New wallpaper configuration UI
  * Preview of wallpaper options including bezels and ppi
    corrections.
  * New bezel configuration through the display preview.
  * New display physical position configuration for PPI
    correction through the display preview.
  * More readable option inputs, only compatible options are
    shown at a time.
  * New help buttons.
  * Pixel density (PPI) correction changes.
  * Now supports arbitrary display arrangements!
  * Bezels are now supported between displays above/below one
    another in addition to next to each other.
  * Automatic PPI detection.
  * NEW perspective corrections
  * Even further improve wallpaper spanning alignment by
    adjusting the image perspective!
  * Perspective setting profiles to enable easy configuration
    with different kinds of wallpapers.
  * Warning if large images would be produced as a result of
    the entered settings.
  * Tool to test perspective options with a user picked image.
  * Display setup options like PPIs and bezel sizes are not stored
    in each wallpaper profile anymore.
  * This means that once you configure the display setup once
    you're good.
  * Perspectives are configured separately and wallpaper profiles
    can use different perspective presets.
  * Wallpaper preview help pop-up tells what the recommended
    wallpaper image size is for best quality.
  * Single images can now be selected as wallpapers in addition to
    folders.
  * Show a busy cursor when user initiates image processing from
    the UI that takes some time.
  * Fix for a scenario where options would not apply when selecting
    'Apply'.
  * A default path to start browsing wallpaper sources can be saved
    from the Browse dialog.
  * Improve application wide setting application during runtime.
* Thu Dec 26 2019 Luigi Baldoni <aloisio@gmx.com>
- Initial package (v1.2.0)
